@@ -22,33 +22,29 @@ try:
 except ImportError:  # pragma: NO COVER
     import mock
 
-import grpc
-from grpc.experimental import aio
 import math
-import pytest
-from proto.marshal.rules.dates import DurationRule, TimestampRule
-from proto.marshal.rules import wrappers
 
+from google.api_core import gapic_v1, grpc_helpers, grpc_helpers_async, path_template
 from google.api_core import client_options
 from google.api_core import exceptions as core_exceptions
-from google.api_core import gapic_v1
-from google.api_core import grpc_helpers
-from google.api_core import grpc_helpers_async
-from google.api_core import path_template
+import google.auth
 from google.auth import credentials as ga_credentials
 from google.auth.exceptions import MutualTLSChannelError
+from google.oauth2 import service_account
+import grafeas.grafeas_v1.types  # type: ignore
+from grafeas.grafeas_v1.types import common  # type: ignore
+import grpc
+from grpc.experimental import aio
+from proto.marshal.rules import wrappers
+from proto.marshal.rules.dates import DurationRule, TimestampRule
+import pytest
+
 from google.cloud.binaryauthorization_v1.services.validation_helper_v1 import (
     ValidationHelperV1AsyncClient,
-)
-from google.cloud.binaryauthorization_v1.services.validation_helper_v1 import (
     ValidationHelperV1Client,
+    transports,
 )
-from google.cloud.binaryauthorization_v1.services.validation_helper_v1 import transports
 from google.cloud.binaryauthorization_v1.types import service
-from google.oauth2 import service_account
-from grafeas.grafeas_v1.types import attestation  # type: ignore
-from grafeas.grafeas_v1.types import common  # type: ignore
-import google.auth
 
 
 def client_cert_source_callback():
